@@ -4,7 +4,7 @@ class languagestring(object):
 	def __init__(self):
 		self.string = string
 
-		with open(f'{os.path.realpath(__file__)}/assets/language_detailed.json','r') as f:
+		with open(f'{os.path.realpath(__file__)}/languagestring/assets/language_detailed.json','r') as f:
 			self.language_dict = json.load(f)
 			f.close()
 
